@@ -138,7 +138,7 @@ add_audio_session (GstElement *pipeline, FsConference *conf, guint id,
   g_value_init (&param.value, FS_TYPE_CANDIDATE_LIST);
   g_value_take_boxed (&param.value, cands);
 
-  res = fs_stream_set_transmitter (ses->stream, "rawudp", &param, 1, &error);
+  fs_stream_set_transmitter (ses->stream, "rawudp", &param, 1, &error);
   print_error (error);
   g_assert (ses->stream);
 
@@ -162,7 +162,7 @@ add_audio_session (GstElement *pipeline, FsConference *conf, guint id,
   codecs = g_list_prepend (codecs,
       fs_codec_new (FS_CODEC_ID_ANY, "PCMU", FS_MEDIA_TYPE_AUDIO, 0));
 
-  res = fs_session_set_codec_preferences (ses->session, codecs, &error);
+  fs_session_set_codec_preferences (ses->session, codecs, &error);
   print_error (error);
   fs_codec_list_destroy (codecs);
 
